pub enum UninstallOutcome {
Removed,
NotFound,
}Expand description
Result of a key removal attempt.
Variants
Removed
The key was found and removed from the remote authorized_keys.
NotFound
The key was not present in the remote authorized_keys.